@@ -2,7 +2,6 @@
 
 from suite_py.lib import logger, metrics
 from suite_py.lib.handler import prompt_utils
-from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.github_handler import GithubHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.symbol import CHECKMARK, CROSSMARK
@@ -16,11 +15,9 @@ class Check:
         self._youtrack = YoutrackHandler(config, tokens)
         self._github = GithubHandler(tokens)
         self._captainhook = captainhook
-        self._drone = DroneHandler(config, tokens)
 
         self._checks = [
             ("Github", self._check_github),
-            ("Drone", self._check_drone),
             ("Youtrack", self._check_youtrack),
             ("CaptainHook", self._check_captainhook),
             ("AWS", self._check_aws),
@@ -52,21 +49,6 @@ class Check:
             self._invalid_or_missing_tokens.append("github")
             return "missing_token"
 
-    def _check_drone(self):
-        if self._tokens.drone:
-            try:
-                drone_user = self._drone.get_user()
-                if "message" in drone_user and drone_user["message"] == "Unauthorized":
-                    self._invalid_or_missing_tokens.append("drone")
-                    return "invalid_token"
-                return "ok"
-            except Exception:
-                logger.debug("Error connecting to drone", exc_info=True)
-                return "unreachable"
-        else:
-            self._invalid_or_missing_tokens.append("drone")
-            return "missing_token"
-
     def _check_youtrack(self):
         if self._tokens.youtrack:
             try:
