@@ -17,10 +17,21 @@ class Context:
 
     # Call the function to_call with kwargs, injecting fields from self as default arguments
     def call(self, to_call, **kwargs):
-        provided = dataclasses.asdict(self)
+        provided = self.shallow_dict()
         needed = signature(to_call).parameters.keys()
         provided = {k: provided[k] for k in needed if k in provided}
 
         kwargs = provided | kwargs
 
         return to_call(**kwargs)
+
+    def shallow_dict(self):
+        """
+        Converts the dataclass to a dict.
+
+        Unlike dataclasses.asdict this function only shallow copies the fields
+        instead of using copy.deepcopy()
+        """
+        return {
+            field.name: getattr(self, field.name) for field in dataclasses.fields(self)
+        }
