@@ -74,9 +74,10 @@ class OpenPR:
                 f"Creating pull request on the {self._project} project for the {self._branch_name} branch linked with the {youtrack_id} card"
             )
             link = self._youtrack.get_link(youtrack_id)
-            title = (
-                f"[{youtrack_id}]: {self._youtrack.get_issue(youtrack_id)['summary']}"
-            )
+
+            default_title = self._youtrack.get_issue(youtrack_id)["summary"]
+            title_without_prefix = _ask_for_title(default_title)
+            title = f"[{youtrack_id}]: {title_without_prefix}"
         else:
             logger.warning(
                 f"Creating pull request on the {self._project} project for the {self._branch_name} branch NOT linked to YouTrack card"
@@ -173,9 +174,11 @@ class OpenPR:
         return description
 
 
-def _ask_for_title():
-    title = prompt_utils.ask_questions_input("Enter the title of the pull request: ")
+def _ask_for_title(default_title=""):
+    title = prompt_utils.ask_questions_input(
+        "Enter the title of the pull request: ", default_title
+    )
     if title == "":
         logger.warning("The title of the pull request cannot be empty")
-        return _ask_for_title()
+        return _ask_for_title(default_title)
     return title
