@@ -23,6 +23,7 @@ WORKABLE_CARD_TYPES = [
 ]
 
 
+# pylint: disable=too-many-public-methods
 class YoutrackHandler:
     def __init__(self, config, tokens):
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
@@ -43,9 +44,15 @@ class YoutrackHandler:
 
     def get_issue(self, issue_id):
         logger.debug(f"YouTrack issue_id: {issue_id}")
-        params = {
-            "fields": "$type,id,idReadable,summary,parent(issues(id)),customFields(name,value(name))"
-        }
+        _fields = [
+            "$type",
+            "id",
+            "idReadable",
+            "summary",
+            "parent(issues(id))",
+            "customFields(name,value(name))",
+        ]
+        params = {"fields": ",".join(_fields)}
         issue = self._client.get(f"issues/{issue_id}", params=params).json()
         issue["Type"] = self._get_issue_type_name(issue)
         logger.debug(f"YouTrack Issue json {issue}")
@@ -214,3 +221,69 @@ class YoutrackHandler:
         parent = issue["parent"]["issues"][0]
         # recursively get parent issue's type
         return self.get_issue(parent["id"])["Type"]
+
+    def get_issue_descendants(self, issue_id):
+        _fields = [
+            "resolved",
+            "subtasks(issues(id,idReadable,resolved,summary,customFields(name,value),subtasks(issues(id))))",
+        ]
+        params = {"fields": ",".join(_fields)}
+        issue = self._client.get(f"issues/{issue_id}", params=params).json()
+
+        descendants = []
+        for child in issue.get("subtasks", {}).get("issues", []):
+            descendants.append(child)
+            if child.get("subtasks", {}).get("issues"):
+                descendants.extend(self.get_issue_descendants(child["id"]))
+        return descendants
+
+    def get_current_sprint(self, agile_board_id):
+        params = {
+            "fields": "id",
+        }
+        return self._client.get(
+            f"agiles/{agile_board_id}/sprints/current", params=params
+        ).json()
+
+    def get_sprints(self, agile_board_id):
+        params = {
+            "fields": "id",
+        }
+        return self._client.get(
+            f"agiles/{agile_board_id}/sprints", params=params
+        ).json()
+
+    def get_sprint_resolved_story_points(self, agile_board_id, sprint_id):
+        """Get the sum of the story point estimates of all resolved issues of a sprint."""
+        params = {
+            "fields": "id,name,goal,issues(id,idReadable,summary,resolved,customFields(name,value))",
+        }
+        sprint = self._client.get(
+            f"agiles/{agile_board_id}/sprints/{sprint_id}", params=params
+        ).json()
+
+        resolved_issues = [issue for issue in sprint["issues"] if issue["resolved"]]
+
+        total_story_points = 0
+        for issue in resolved_issues:
+            # Find the Story Points custom field
+            story_points_field = next(
+                (
+                    field
+                    for field in issue.get("customFields", [])
+                    if field["name"] == "Story Points"
+                ),
+                None,
+            )
+            if story_points_field and story_points_field.get("value"):
+                try:
+                    story_points = int(story_points_field["value"])
+                    total_story_points += story_points
+                except (ValueError, TypeError):
+                    # Skip issues with invalid story points values
+                    logger.debug(
+                        f"Invalid story points value for issue {issue.get('idReadable', 'unknown')}: {story_points_field.get('value')}"
+                    )
+                    continue
+
+        return total_story_points
