@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 import functools
-from suite_py.lib.config import Config
 
+from suite_py.lib.config import Config
 from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.metrics_handler import Metrics
 
@@ -12,7 +12,7 @@ def _metrics() -> Metrics:
     if _metrics_handler:
         return _metrics_handler
 
-    raise Exception(
+    raise RuntimeError(
         "command_executed called before logger.setup(). This is a bug, please report it"
     )
 
